@@ -20,7 +20,7 @@ except ImportError:
     from configs import configs
     from data import models_dict, metrics_dict
     from preprocessing import update_dataset_props
-    from preprocessing import handle_missing_values
+    from preprocessing import handle_missing_values, encode, normalize
 
 from sklearn.model_selection import train_test_split
 
@@ -151,11 +151,23 @@ class IgelModel(object):
             # handle missing values in the dataset
             preprocess_props = self.dataset_props.get('preprocess', None)
             if preprocess_props:
+                # handle encoding
+                encoding = preprocess_props.get('encoding')
+                if encoding:
+                    encoding_type = encoding.get('type', None)
+                    column = encoding.get('column', None)
+                    dataset = encode(df=dataset,
+                                     encoding_type=encoding_type.lower(),
+                                     column=column)
+                    logger.info(f"shape of the dataset after encoding => {dataset.shape}")
+
                 # preprocessing strategy: mean, median, mode etc..
                 strategy = preprocess_props.get('missing_values')
                 if strategy:
                     dataset = handle_missing_values(dataset,
                                                     strategy=strategy)
+                    logger.info(f"shape of the dataset after handling missing values => {dataset.shape}")
+
 
             if any(col not in attributes for col in self.target):
                 raise Exception("chosen target(s) to predict must exist in the dataset")
@@ -164,6 +176,21 @@ class IgelModel(object):
             x = _reshape(dataset.to_numpy())
             y = _reshape(y.to_numpy())
             logger.info(f"y shape: {y.shape} and x shape: {x.shape}")
+
+            # handle data scaling
+            if preprocess_props:
+                scaling_props = preprocess_props.get('scale', None)
+                if scaling_props:
+                    scaling_method = scaling_props.get('method', None)
+                    scaling_target = scaling_props.get('target', None)
+                    if scaling_target == 'all':
+                        x = normalize(x, method=scaling_method)
+                        y = normalize(y, method=scaling_method)
+                    elif scaling_target == 'inputs':
+                        x = normalize(x, method=scaling_method)
+                    elif scaling_target == 'outputs':
+                        y = normalize(y, method=scaling_method)
+
             if not fit:
                 return x, y
 
@@ -281,9 +308,8 @@ class IgelModel(object):
 
 
 if __name__ == '__main__':
-    mock_params = {'data_path': '/home/nidhal/my_projects/igel/examples/data/indians-diabetes.csv',
-                   'yaml_path': '/home/nidhal/my_projects/igel/examples/model.yaml'}
-
+    mock_params = {'data_path': '/home/nidhal/my_projects/igel/examples/data/Iris.csv',  # '/home/nidhal/my_projects/igel/examples/data/indians-diabetes.csv',
+                   'yaml_path': '/home/nidhal/my_projects/igel/examples/iris_example.yaml'}
     reg = IgelModel('fit', **mock_params)
     reg.fit()
     # reg.predict()
